#! /bin/bash 
#
#   Print pid and count for specified shm partition
smp_data() {
    echo "0 `${exec_prefix}/bin/smstat buffer_tot $1`"
    ${exec_prefix}/bin/smdump -c $1 \
      | grep '^ ' \
      | grep -v 'id' \
      | sed -e 's,^ *,,g' -e 's,  *, ,g' \
      | cut -d ' ' -f 2,6
}

export TERM=${TERM:-dumb}

#######################################
#        Initialize the stuff         #
#######################################
export TERM=${TERM:-dumb}
prefix=/usr
exec_prefix=${prefix}
datarootdir=${prefix}/share
sd=$HOME/dmtspi/cache
td=${datarootdir}/gds/Spi
user=`whoami`
opsuser=${PROCMGT_PROCESS_ROOT:-$user}

#---------------------------------------  Parse the comman line
while [ $# != 0 ]; do
    if [ `echo $1 | grep -c '^--gds-config='` != 0 ]; then
	td="`echo $1 | sed -e 's,^--gds-config=,,'`/Spi"
    elif [ `echo $1 | grep -c '^--local_html='` != 0 ]; then
	dh=`echo $1 | sed -e 's,^--local_html=,,'`
    fi
    shift
done

TOP=`which top`;
if [ "$OSName" = "SunOS" ]; then
    TOPCMD="$TOP -d12 -s1 200"
else
    TOPCMD="$TOP -b -d1 -n1 -u$opsuser"
fi

mkdir -p $sd
TD="/tmp"

#---------------------------------------  Get host description from HOST.lookup
# field  variable Contents
#   1             Node name (e.g. "host")
#   2     g       Node ID   (e.g. "HOST")
#   3     gIP     Domain name (e.g. ligo-wa)
#   4     gLN     Domain ID   (e.g. "LHO")
#   5             URL of dmt top directory
#   6             Master / Slave
#   7     dh      Top web directory path
#
gn=`uname -n | cut -d. -f1`
if [ `grep -c "^$gn" $td/HOST.lookup` -gt 1 ]; then
    domain=`domainname`
    if [ $domain = "(none)" ]; then
        domain=`grep '^search ' /etc/resolv.conf \
	      | sed -e 's,^search  *,,g' -e 's, .*$,,g'`
    fi
    domain=`echo $domain | sed -e 's,\.caltech\.edu,,g'`
    hostl=`grep "^$gn" $td/HOST.lookup | grep $domain`
else
    hostl=`grep "^$gn" $td/HOST.lookup`
fi

if [ -z "$hostl" ]; then
   hostl="$gn GDSLOCAL ligo https://ldas-jobs.ligo.caltech.edu/~$user/gds M \
         $HOME/public_html/gds"
fi

#---------------------------------------  Parse the host line.
#                                         Note: echo removes extra spaces.
g=`echo $hostl | cut -d ' ' -f 2`
gip=`echo $hostl | cut -d ' ' -f 3`
gLN=`echo $hostl | cut -d ' ' -f 4`
[ -z "$dh" ] && dh=`echo $hostl | cut -d ' ' -f 7`

#---------------------------------------  Define spi output (Monitors) directory
dd="$dh/Monitors"
mkdir -p $dd/$g

#######################################
#  Look for frame consumption         #
#######################################
parts=`smlist | sed -e 's,^ *,,g' -e 's,  *, ,g' | 
	        cut -d ' ' -f 2 | grep -v name`
for p in $parts; do
    alist="$TD/After_${g}_${p}.list"
    blist="$TD/Before_${g}_${p}.list"
    tlist="$TD/Temp_${g}_${p}.list"
    smp_data $p > $tlist
    mv $alist $blist
    mv $tlist $alist
done

#######################################
#  Prepare DMT diagnostic info files  #
#######################################
# Add TOP info
$TOPCMD \
  | sed -f $td/top-html.sed \
  >  $dd/$g/TOPinfo_t.html
echo "<br><br><br>" \
  >> $dd/$g/TOPinfo_t.html

#--------------------------------------- This doesn't work in linux
#  | nawk -f $td/AT.script 
#

mv $dd/$g/TOPinfo_t.html $dd/$g/TOPinfo.html
